from numtoname.functions import generate_name_fixed
from numtoname.functions import generate_names_fixed
from numtoname.functions import generate_name
from numtoname.functions import generate_names
from numtoname.functions import generate_name_fixed_alpha
from numtoname.functions import generate_names_fixed_alpha
from numtoname.functions import generate_name_alpha
from numtoname.functions import generate_names_alpha
from numtoname.functions import generate_name_fixed_alpha2
from numtoname.functions import generate_names_fixed_alpha2
from numtoname.functions import generate_name_alpha2
from numtoname.functions import generate_names_alpha2
